@@ -1,10 +1,13 @@
 
 package Role::Log::Syslog::Fast;
 
+use strict;
 use Moose::Role;
 use Log::Syslog::Fast ':all';
 
-our $VERSION = '0.12';
+# ABSTRACT: A Logging role for L<Moose> on L<Log::Syslog::Fast>
+
+our $VERSION = '0.13'; # VERSION
 
 has '_proto' => (
     is      => 'rw',
@@ -15,7 +18,8 @@ has '_proto' => (
 has '_hostname' => (
     is      => 'rw',
     isa     => 'Str',
-    default => '/dev/log'
+    lazy    => 1,
+    default => sub { -f '/dev/log' ? '/dev/log' : '/dev/klog' }
 );
 
 has '_port' => (
@@ -52,28 +56,34 @@ has '_logger' => (
     is      => 'ro',
     isa     => 'Log::Syslog::Fast',
     lazy    => 1,
-    default => sub { 
+    default => sub {
         my $self = shift;
         return Log::Syslog::Fast->new(
             $self->_proto, $self->_hostname, $self->_port,
-            $self->_facility, $self->_severity, $self->_sender, 
-            $self->_name); 
-    } 
+            $self->_facility, $self->_severity, $self->_sender,
+            $self->_name);
+    }
 );
 
-sub log { 
+sub log {
     my ($self, $msg, $time) = @_;
-    return $time 
+    return $time
         ? $self->_logger->send($msg, $time) : $self->_logger->send($msg);
 }
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-MooseX::Log::Syslog::Fast - A Logging role for L<Moose> on L<Log::Syslog::Fast>
+Role::Log::Syslog::Fast - A Logging role for L<Moose> on L<Log::Syslog::Fast>
+
+=head1 VERSION
+
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -93,7 +103,7 @@ MooseX::Log::Syslog::Fast - A Logging role for L<Moose> on L<Log::Syslog::Fast>
             my $self = shift;
             $self->log('foo');
         }
-    
+
     }
 
     my $obj = new ExampleLog;
@@ -104,6 +114,16 @@ MooseX::Log::Syslog::Fast - A Logging role for L<Moose> on L<Log::Syslog::Fast>
 
 A logging role building a very lightweight wrapper to L<Log::Syslog::Fast> for use with L<Moose> classes.
 
+=head1 NAME
+
+MooseX::Log::Syslog::Fast - A Logging role for L<Moose> on L<Log::Syslog::Fast>
+
+=head1 METHOD
+
+=head2 log
+
+(message, [time])
+
 =head1 SEE ALSO
 
 L<Log::Syslog::Fast>, L<Log::Syslog>, L<Moose>
@@ -122,9 +142,24 @@ Thiago Rondon <thiago@aware.com.br>
 
 This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Thiago Rondon <thiago@nsms.com.br>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Thiago Rondon.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
 
+__END__
+
+
+
 1;
 
 
